@@ -5,13 +5,13 @@ import time
 
 sys.path.append(os.path.join(os.path.dirname(__file__), os.path.pardir))
 
-from uasparser2 import UASparser
+from uasparser2 import UASParser
 
 test_uas = json.load(open('test/uas.json', 'r'))
 
 t0 = time.time()
-up = UASparser(mem_cache_size=0)
-print 'load:', time.time() - t0
+up = UASParser(mem_cache_size=100)
+print ('load:', time.time() - t0)
 
 t0 = time.time()
 for uas, obj in test_uas:
@@ -20,13 +20,12 @@ for uas, obj in test_uas:
 
         assert new_obj == obj
     except Exception:
-        print
-        print uas
+        raise
+        print()
+        print(uas)
         for k in set(new_obj.keys()) | set(obj.keys()):
             if obj.get(k) != new_obj.get(k):
-                print k, '\t', obj.get(k, '').encode('utf-8'), '\t', new_obj.get(k, '').encode('utf-8')
+                print(k, '\t', obj.get(k, '').encode('utf-8'), '\t', new_obj.get(k, '').encode('utf-8'))
 
-print
-print 'parse:', time.time() - t0
-
-print 'cahce', up.mem_cache.stats_hit, up.mem_cache.stats_miss
+print()
+print ('parse:', time.time() - t0)
